@@ -1,7 +1,7 @@
 package App::riap;
 
-our $DATE = '2015-02-18'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2015-03-04'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -550,7 +550,7 @@ sub comp_ {
     my $comp = Complete::Bash::format_completion({
         path_sep => '/',
         as       => 'array',
-        escmode  => 'default',
+        esc_mode => 'default',
         words    => Complete::Util::complete_array_elem(
             array=>\@res, word=>$word0),
     });
@@ -644,7 +644,7 @@ sub catch_comp {
     @{ Complete::Bash::format_completion({
         path_sep => '/',
         as       => 'array',
-        escmode  => 'default',
+        esc_mode => 'default',
         words    => Complete::Util::complete_array_elem(
             array=>$res->{words}, word=>$word),
     })};
@@ -707,7 +707,7 @@ sub _install_cmds {
             my $comp = Complete::Bash::format_completion({
                 path_sep => '/',
                 as       => 'array',
-                escmode  => 'default',
+                esc_mode => 'default',
                 words    => Complete::Util::complete_array_elem(
                     array=>$res->{words}, word=>$word),
             });
@@ -740,7 +740,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
